package Chooser::Checks::hostregex;

use warnings;
use strict;
use base 'Error::Helper';
use Sys::Hostname;

=head1 NAME

Chooser::Check::hostregex - This provides the hostregex check for Chooser.

=head1 VERSION

Version 0.0.0

=cut

our $VERSION = '0.0.0';

=head1 METHODS

=head2 new

This initiates the object.

No arguments are taken and this will
never error.

    my $check=Chooser::Check::hostregex->new;

=cut

sub new{

	my $self={
		error=>undef,
		perror=>undef,
		errorString=>undef,
		errorExtra=>{
			flags=>{
				'1'=>'noRegex',
			},
		},
	};
	bless $self;

	return $self;
}

=head2 test

This runs the test.

=cut

sub test{
	my $self=$_[0];
	my %args= %{$_[1]};

	if ( ! defined( $args{regex} ) ){
		$self->{error}=1;
		$self->{errorString}='No regex specified';
		$self->warn;
		return undef;
	}
	
	if (hostname =~ /$args{regex}/){
		return "1";
	}
	
	return "0";
}

=head1 ERROR CODES/FLAGS

=head2 1, noRegex

No regular expression specified. 'regex' arg is undefined.

=head1 BUGS

Please report any bugs or feature requests to C<bug-chooser at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Chooser>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Chooser::Checks::hostregex

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Chooser>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Chooser>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Chooser>

=item * Search CPAN

L<http://search.cpan.org/dist/Chooser>

=back

=head1 COPYRIGHT & LICENSE

Copyright 2012 Zane C. Bowers-Hadley, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut

1; # End of Chooser::Checks::hostregex
